@@ -8,14 +8,17 @@ from grtoolkit.Storage import File
 from grtoolkit.PowerPoint import duplicate_slide
 
 # parent = dirname(sys.argv[0])
-parent = os.getcwd()
+# parent = os.getcwd()
+parent = r"D:\OneDrive\Development\Life\The Truth"
 QUOTES = f'{parent}\\Quotes.txt'
 OLD_PPT = f'{parent}\\QUOTE_PPT_TEMPLATE.pptm'
 NEW_PPT = f'{parent}\\QUOTE_NEW.pptm'
 
+# QUOTES = 
+
 prs = Presentation(OLD_PPT)
 
-QUOTESContent = File(QUOTES).read()
+QUOTESContent = File(QUOTES, enc=1).read()
 QUOTESList = QUOTESContent.split("\n\n")
 
 #DUPLICATE PPT SLIDE FOR EVERY 
